"use client";

import ShinyButton from "@/components/ui/shiny-button";
import { useTabsContext } from "@/contexts/tabs-context";
import { motion } from "framer-motion";
import { useLocale, useTranslations } from "next-intl";
import Image from "next/image";


type ProductRecordType = {
	name: string;
	price: number;
	className?: string;
	color?: string;
};

const ProductRecord = ({
	name,
	price,
	className = "",
	color,
}: ProductRecordType) => {
	return (
		<div
			className={`flex items-center justify-between ${className} transition-transform duration-300 hover:scale-105`}
		>
			<div className="flex items-center gap-2">
				<p
					style={color ? { color: color } : {}}
					className={"text-sm font-medium text-custom-primary-accent"}
				>
					{price}
				</p>
				<Image
					src={"/coins/Saudi_Riyal.jpg"}
					alt="Saudi_Riyal"
					width={12}
					height={12}
				/>
			</div>
			<p
				style={color ? { color: color } : {}}
				className={"text-sm text-custom-primary-accent w-[160px]"}
			>
				{name}
			</p>
		</div>
	);
};

function PurchaseInvoice({ invoice }: any) {
	const locale = useLocale();
	const t = useTranslations("Cart");
	const { tabsRef } = useTabsContext();

	const handleCompleteProcess = () => {
		// Navigate to the Invoice tab (index 1)
		if (tabsRef?.current) {
			tabsRef.current.setActiveTab(1);
		}
	};

	return (
		<motion.section
			initial={{ opacity: 0, y: 20 }}
			animate={{ opacity: 1, y: 0 }}
			transition={{ duration: 0.5 }}
			className="mx-auto min-w-full rounded-md p-4 transition-shadow duration-300 hover:shadow-lg md:p-4 lg:min-w-[250px] lg:p-6 xl:min-w-[340px] xl:p-6"
			style={{
				border: "1px solid #2895C8",
				boxShadow: "0px 4px 4px 0px #00000040",
			}}
		>
			<p className="text-xl leading-7 text-custom-primary-accent lg:text-[28px]">
				{t("PurchaseInvoice")}
			</p>

			<div className="my-2 text-end md:my-4 lg:my-8 xl:my-9">
				{invoice?.data?.length > 0 ? (
					invoice?.data?.map((product: any) => (
						<ProductRecord
							key={product.id}
							name={locale === "ar" ? product?.product?.name_ar : product?.product?.name_en}
							price={parseFloat(product?.product?.base_price) * product?.quantity}
							className="mb-3"
						/>
					))
				) : (
					<div className="flex flex-col gap-3">
						<div className="h-6 w-full animate-pulse rounded bg-gray-200"></div>
						<div className="h-6 w-full animate-pulse rounded bg-gray-200"></div>
						<div className="h-6 w-full animate-pulse rounded bg-gray-200"></div>
					</div>
				)}
				<div style={{ border: "0.8px solid #E4E4E4" }} className="mb-6" />

				<ProductRecord
					name={t("TotalCost")}
					price={invoice?.subtotal?.toFixed(2)}
					color="#8E8F94"
					className="mb-3"
				/>
				<ProductRecord
					name={t("AdditionalTaxes")}
					price={invoice?.vat_value?.toFixed(2)}
					color="#8E8F94"
					className="mb-3"
				/>
				<ProductRecord name={t("TotalPrice")} price={invoice?.grand_total?.toFixed(2)} className="mb-3" />
			</div>

			<ShinyButton
				className="w-full rounded-3xl bg-custom-primary-accent py-3 transition-transform duration-300 hover:scale-105"
				onClick={handleCompleteProcess}
			>
				<p className="w-full text-base text-white">{t("CompleteProcess")}</p>
			</ShinyButton>
		</motion.section>
	);
}

export default PurchaseInvoice;
